"""Implementation of XBAfunction class.

Peter Schubert, HHU Duesseldorf, May 2022
"""

import re
import sbmlxdf


class XbaFunction:

    def __init__(self, s_function):
        self.id = s_function.name
        self.name = s_function.get('name', '')
        self.math = s_function['math']

        m = re.search(r'\blambda\((.*)\)', sbmlxdf.misc.mathml2numpy(s_function['math']))
        if m and len(m.groups()) > 0:
            lambda_def = [kw.strip() for kw in m.group(1).split(',')]
            lambda_func = lambda_def[-1]
            lambda_params = []
            # parameters getting protected by prefix/postfix of '_'
            for param in lambda_def[:-1]:
                lambda_params.append('_' + param + '_')
                lambda_func = re.sub(r'\b' + param + r'\b', '_' + param + '_', lambda_func)

            self.protect_def = lambda_func
            self.protect_params = lambda_params

    def get_function(self):
        return self.protect_def, self.protect_params
